/*

Copyright (C) 2010 NTT DATA Corporation

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.

 */

package com.clustercontrol.selfcheck.monitor;

import com.clustercontrol.bean.HinemosModuleConstant;
import com.clustercontrol.repository.bean.FacilityTreeAttributeConstant;

/**
 * セルフチェック機能の処理実装の抽象クラス
 */
public abstract class SelfCheckMonitorBase implements SelfCheckMonitor {

	protected static final String PLUGIN_ID = HinemosModuleConstant.SYSYTEM_SELFCHECK;
	protected static final String FACILITY_ID = FacilityTreeAttributeConstant.INTERNAL_SCOPE;
	protected static final String FACILITY_TEXT = FacilityTreeAttributeConstant.INTERNAL_SCOPE_TEXT;

}
